@@ -7,6 +7,7 @@
 ##' @docType methods
 ##' @include pomp_class.R
 ##' @importFrom stats setNames
+##' @family extraction methods
 ##'
 NULL
 
@@ -38,3 +39,14 @@ setMethod(
     x
   }
 )
+
+##' @rdname states
+##' @inheritParams obs
+##' @export
+setMethod(
+  "states",
+  signature=signature(object="listie"),
+  definition=function (object, vars, ...) {
+    lapply(object,states)
+  }
+)
