@@ -94,7 +94,7 @@ static R_INLINE SEXP eval_call (
 static R_INLINE SEXP ret_array (int n, int nreps, int ntimes, SEXP names)
 {
   int dim[3] = {n, nreps, ntimes};
-  const char *dimnm[3] = {"variable", "rep", "time"};
+  const char *dimnm[3] = {"variable", ".id", "time"};
   SEXP Y;
 
   PROTECT(Y = makearray(3,dim));
